# MCP4725

Microchip 4725 Digital-to-Analog Converter

- Device address 98
- Address type 7-bit
- Little Endian

### Addr 64 12-bytes | # Output voltage ## VOut = (Vcc * value) / 4096 The output is a range between 0 and Vcc with steps of Vcc/4096. In a 3.3v system, each step is 800 microvolts.
### Addr 96 12-bytes | # Digital (binary) output ## Only allows you to send fully on or off ### [12:0] | 13-bytes

## Functions

- getVOut.asVoltage - get vout
- setVOut.asVoltage - set vout